aboutsummaryrefslogtreecommitdiffstats
path: root/scripts/clean_test_env.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/clean_test_env.sh')
-rwxr-xr-xscripts/clean_test_env.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/scripts/clean_test_env.sh b/scripts/clean_test_env.sh
index 6edef41..f6b6867 100755
--- a/scripts/clean_test_env.sh
+++ b/scripts/clean_test_env.sh
@@ -10,9 +10,10 @@ pkill -x "neko_server" || true
pkill -f "vite" || true
pkill -f "playwright" || true
# Kill anything on ports 4994 and 5173
fuser -k 4994/tcp || true
fuser -k 5173/tcp || true
+fuser -k 9090/tcp || true
# Remove test databases
rm -f neko_test.db .data/test.db
@@ -10,9 +10,10 @@ pkill -x "neko_server" || true
pkill -f "vite" || true
pkill -f "playwright" || true
-# Kill anything on ports 4994 and 5173
+# Kill anything on ports 4994 and 5173 and 9090
fuser -k 4994/tcp || true
fuser -k 5173/tcp || true